@@ -5,13 +5,12 @@ import json
 import os
 from abc import abstractmethod
 from typing import Any, List, Optional, final
-
+from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 from hoppr import plugin_utils
 from hoppr.base_plugins.hoppr import HopprPlugin, hoppr_process, hoppr_rerunner
 from hoppr.configs.credentials import Credentials
 from hoppr.result import Result
-from hoppr.types.cred_object import CredObject
-from hoppr.types.cyclonedx_1_4 import Component
+from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.utils import dedup_list, remove_empty
 
 
