@@ -16,7 +16,7 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:  # pragma: no cover
     from hoppr.configs.manifest import Manifest
-    from hoppr.types.cyclonedx_1_4 import (
+    from hoppr_cyclonedx_models.cyclonedx_1_4 import (
         CyclonedxSoftwareBillOfMaterialsStandard as Bom,
     )
 
@@ -30,5 +30,6 @@ class Context:
     manifest: Manifest
     collect_root_dir: str
     consolidated_sbom: Bom
+    max_processes: int
     max_attempts: int = 3
     retry_wait_seconds: float = 5
