@@ -11,7 +11,7 @@ from hoppr.base_plugins.collector import CollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
 from hoppr.result import Result
-from hoppr.types.cred_object import CredObject
+from hoppr.hoppr_types.cred_object import CredObject
 
 _DEFAULT_MAVEN_EXT = "tar.gz"
 _MAVEN_DEP_PLUGIN = "org.apache.maven.plugins:maven-dependency-plugin:2.5.1"
