@@ -4,6 +4,7 @@ Run Hoppr processing, using multiple processors
 from __future__ import annotations
 
 import logging
+from multiprocessing import cpu_count
 import os
 import platform
 import shutil
@@ -18,6 +19,7 @@ from typing import Dict, List, Optional, Tuple
 
 from packageurl import PackageURL  # type: ignore
 from typer import echo
+from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 
 from hoppr.base_plugins.hoppr import HopprPlugin
 from hoppr.configs.manifest import Manifest
@@ -27,8 +29,7 @@ from hoppr.exceptions import HopprPluginError
 from hoppr.flatten_sboms import flatten_sboms
 from hoppr.net import download_file
 from hoppr.result import Result
-from hoppr.types.cyclonedx_1_4 import Component
-from hoppr.types.transfer_file_content import Plugin as PluginRef
+from hoppr.hoppr_types.transfer_file_content import Plugin as PluginRef
 from hoppr.utils import plugin_instance
 
 if "nux" in platform.system():
@@ -59,16 +60,11 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
     """
 
     def __init__(
-        self,
-        stage_id: str,
-        context: Context,
-        plugin_ref_list: List[PluginRef],
-        max_processes=3,
+        self, stage_id: str, context: Context, plugin_ref_list: List[PluginRef]
     ):
         self.stage_id = stage_id
         self.context = context
         self.plugin_ref_list = plugin_ref_list
-        self.max_processes = max_processes
         self.plugins: List[HopprPlugin] = []
         self.results: Dict = {}
 
@@ -109,7 +105,7 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
         # Map to allow access to the arguments that went into a future call
         future_argument_map: Dict[Future, Tuple[HopprPlugin, Optional[Component]]] = {}
 
-        with ProcessPoolExecutor(max_workers=self.max_processes) as executor:
+        with ProcessPoolExecutor(max_workers=self.context.max_processes) as executor:
             for plugin in self.plugins:
                 if method_name in component_based_methods:
 
@@ -309,11 +305,11 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
         total_failure_count = 0
         for stage_id, stage in self.stages.items():
             echo(f"\nStage: {stage_id}")
-            failure_list = "\n      Failure Summary:\n"
             for method_name, result_list in stage.results.items():
                 echo(f"   {method_name}")
                 result_count = len(result_list)
                 failure_count = 0
+                failure_list = "\n      Failure Summary:\n"
                 for plugin_name, comp_str, result in result_list:
 
                     # All retries should be handled internally by the plugins,
@@ -351,8 +347,14 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
                 manifest=self.manifest,
                 collect_root_dir=collection_root,
                 consolidated_sbom=flatten_sboms(self.manifest),
+                max_processes=cpu_count(),
             )
+            if self.transfer.content:
+                self.context.max_processes = self.transfer.content.max_processes
 
+            self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
+                f"Beggining Hoppr Process execution, max_processes={self.context.max_processes}"
+            )
             self._collect_metadata()
 
             if self.transfer.content is not None:
